@@ -1,14 +1,15 @@
 #' Store the eBird Status and Trends access key
 #'
 #' Accessing eBird Status and Trends data requires an access key, which can be
-#' obtained by visiting https://ebird.org/st/request. This key must be
-#' stored as the environment variable `EBIRDST_KEY` in order for
-#' [ebirdst_download()] to use it. The easiest approach is to store the key in
-#' your `.Renviron` file so it can always be accessed in your R sessions. Use
-#' this function to set `EBIRDST_KEY` in your `.Renviron` file provided that it
-#' is located in the standard location in your home directory. It is also
-#' possible to manually edit the `.Renviron` file. **The access key is specific
-#' to you and should never be shared or made publicly accessible.**
+#' obtained by visiting https://ebird.org/st/request. This key must be stored as
+#' the environment variable `EBIRDST_KEY` in order for
+#' [ebirdst_download_status()] and [ebirdst_download_trends()] to use it. The
+#' easiest approach is to store the key in your `.Renviron` file so it can
+#' always be accessed in your R sessions. Use this function to set `EBIRDST_KEY`
+#' in your `.Renviron` file provided that it is located in the standard location
+#' in your home directory. It is also possible to manually edit the `.Renviron`
+#' file. **The access key is specific to you and should never be shared or made
+#' publicly accessible.**
 #'
 #' @param key character; API key obtained by filling out the form at
 #'   https://ebird.org/st/request.
@@ -52,8 +53,11 @@ set_ebirdst_access_key <- function(key, overwrite = FALSE) {
   } else {
     write(paste0("\n", key_line, "\n"), renv_path, append = TRUE)
   }
-  message("eBird Status and Trends access key stored in: ", renv_path,
-          "\nYou must RESTART R to load the saved access key.")
+
+  # set key in memory - for current R session
+  Sys.setenv(EBIRDST_KEY = key)
+
+  message("eBird Status and Trends access key stored in: ", renv_path)
   invisible(renv_path)
 }
 
@@ -64,8 +68,7 @@ get_ebirdst_access_key <- function() {
     message("An access key is required to download eBird Status and Trends ",
             "data\n1. Get a key by filling out the request form at ",
             "https://ebird.org/st/request\n",
-            "2. Save the key using set_ebirdst_access_key()\n",
-            "3. Restart R to load the key")
+            "2. Save the key using set_ebirdst_access_key()\n")
     stop("Valid eBird Status and Trends access key not found. ",
          "Note that keys expire after 1 month, you may need a new key.")
   }
