@@ -272,6 +272,10 @@ load_raster <- function(species,
 load_trends <- function(species,
                         fold_estimates = FALSE,
                         path = ebirdst_data_dir()) {
+  if (!requireNamespace("arrow", quietly = TRUE)) {
+    stop("Package 'arrow' must be installed to load eBird Trends",
+         "data with load_trends().")
+  }
   stopifnot(is.character(species), !is.na(species), dir.exists(path))
   stopifnot(is_flag(fold_estimates))
 
